@@ -716,6 +716,13 @@ def BR_Win32_WritePrivateProfileString(p0,p1,p2,p3):
   r=f(t[0],t[1],t[2],t[3])
   return r
 
+def CF_CreatePreview(p0):
+  a=rpr_getfp('CF_CreatePreview')
+  f=CFUNCTYPE(c_uint64,c_uint64)(a)
+  t=(rpr_packp('PCM_source*',p0),)
+  r=f(t[0])
+  return rpr_unpackp('CF_Preview*',r)
+
 def CF_EnumerateActions(p0,p1,p2,p3):
   a=rpr_getfp('CF_EnumerateActions')
   f=CFUNCTYPE(c_int,c_int,c_int,c_char_p,c_int)(a)
@@ -848,6 +855,60 @@ def CF_LocateInExplorer(p0):
   r=f(t[0])
   return r
 
+def CF_PCM_Source_SetSectionInfo(p0,p1,p2,p3,p4):
+  a=rpr_getfp('CF_PCM_Source_SetSectionInfo')
+  f=CFUNCTYPE(c_byte,c_uint64,c_uint64,c_double,c_double,c_byte)(a)
+  t=(rpr_packp('PCM_source*',p0),rpr_packp('PCM_source*',p1),c_double(p2),c_double(p3),c_byte(p4))
+  r=f(t[0],t[1],t[2],t[3],t[4])
+  return r
+
+def CF_Preview_GetPeak(p0,p1,p2):
+  a=rpr_getfp('CF_Preview_GetPeak')
+  f=CFUNCTYPE(c_byte,c_uint64,c_int,c_void_p)(a)
+  t=(rpr_packp('CF_Preview*',p0),c_int(p1),c_double(p2))
+  r=f(t[0],t[1],byref(t[2]))
+  return (r,p0,p1,float(t[2].value))
+
+def CF_Preview_GetValue(p0,p1,p2):
+  a=rpr_getfp('CF_Preview_GetValue')
+  f=CFUNCTYPE(c_byte,c_uint64,c_char_p,c_void_p)(a)
+  t=(rpr_packp('CF_Preview*',p0),rpr_packsc(p1),c_double(p2))
+  r=f(t[0],t[1],byref(t[2]))
+  return (r,p0,p1,float(t[2].value))
+
+def CF_Preview_Play(p0):
+  a=rpr_getfp('CF_Preview_Play')
+  f=CFUNCTYPE(c_byte,c_uint64)(a)
+  t=(rpr_packp('CF_Preview*',p0),)
+  r=f(t[0])
+  return r
+
+def CF_Preview_SetOutputTrack(p0,p1,p2):
+  a=rpr_getfp('CF_Preview_SetOutputTrack')
+  f=CFUNCTYPE(c_byte,c_uint64,c_uint64,c_uint64)(a)
+  t=(rpr_packp('CF_Preview*',p0),rpr_packp('ReaProject*',p1),rpr_packp('MediaTrack*',p2))
+  r=f(t[0],t[1],t[2])
+  return r
+
+def CF_Preview_SetValue(p0,p1,p2):
+  a=rpr_getfp('CF_Preview_SetValue')
+  f=CFUNCTYPE(c_byte,c_uint64,c_char_p,c_double)(a)
+  t=(rpr_packp('CF_Preview*',p0),rpr_packsc(p1),c_double(p2))
+  r=f(t[0],t[1],t[2])
+  return r
+
+def CF_Preview_Stop(p0):
+  a=rpr_getfp('CF_Preview_Stop')
+  f=CFUNCTYPE(c_byte,c_uint64)(a)
+  t=(rpr_packp('CF_Preview*',p0),)
+  r=f(t[0])
+  return r
+
+def CF_Preview_StopAll():
+  a=rpr_getfp('CF_Preview_StopAll')
+  f=CFUNCTYPE(None)(a)
+  f()
+
 def CF_SelectTrackFX(p0,p1):
   a=rpr_getfp('CF_SelectTrackFX')
   f=CFUNCTYPE(c_byte,c_uint64,c_int)(a)
@@ -955,6 +1016,20 @@ def NF_AnalyzeTakeLoudness_IntegratedOnly(p0,p1):
   r=f(t[0],byref(t[1]))
   return (r,p0,float(t[1].value))
 
+def NF_Base64_Decode(p0,p1,p2):
+  a=rpr_getfp('NF_Base64_Decode')
+  f=CFUNCTYPE(c_byte,c_char_p,c_char_p,c_int)(a)
+  t=(rpr_packsc(p0),rpr_packs(p1),c_int(p2))
+  r=f(t[0],t[1],t[2])
+  return (r,p0,rpr_unpacks(t[1]),p2)
+
+def NF_Base64_Encode(p0,p1,p2,p3,p4):
+  a=rpr_getfp('NF_Base64_Encode')
+  f=CFUNCTYPE(None,c_char_p,c_int,c_byte,c_char_p,c_int)(a)
+  t=(rpr_packsc(p0),c_int(p1),c_byte(p2),rpr_packs(p3),c_int(p4))
+  f(t[0],t[1],t[2],t[3],t[4])
+  return (p0,p1,p2,rpr_unpacks(t[3]),p4)
+
 def NF_ClearGlobalStartupAction():
   a=rpr_getfp('NF_ClearGlobalStartupAction')
   f=CFUNCTYPE(c_byte)(a)
@@ -1064,6 +1139,12 @@ def NF_ReadAudioFileBitrate(p0):
   r=f(t[0])
   return r
 
+def NF_ScrollHorizontallyByPercentage(p0):
+  a=rpr_getfp('NF_ScrollHorizontallyByPercentage')
+  f=CFUNCTYPE(None,c_int)(a)
+  t=(c_int(p0),)
+  f(t[0])
+
 def NF_SetGlobalStartupAction(p0):
   a=rpr_getfp('NF_SetGlobalStartupAction')
   f=CFUNCTYPE(c_byte,c_char_p)(a)
